-- 英雄重修
Lua_HeroRebuildWindow = class("Lua_HeroRebuildWindow", Lua_Window);
function Lua_HeroRebuildWindow:ctor()
    self:superCall("ctor");
    self.isClickClose = true;
    self.showBlackMask = true;
    self.windowName = "Lua_HeroRebuildWindow";
    self.skinName = "HeroRebuildWindow_skin";
end

function Lua_HeroRebuildWindow:buildShowItem()
    self:superCall("buildShowItem");

    self.heroItemIcon = Lua_HeroItemIcon.new(self.content);
    self.heroItemIcon:setLocation(-2,210,0);

    self.dragList = Lua_DragList.new(self.content,620, 168, Lua_AxisDefine.Vertical);
    self.dragList:setListCell(Lua_HeroRebuildCell, 107, 107, 5);
    self.dragList:setCellSpacing(15, 20);
    self.dragList:setLocation(0, -65);

    self.btnList = Lua_ButtonList.new(self.content, Lua_AxisDefine.Horizontal);
    self.btnList:setRectAnchor(1);
    self.btnList:setButtonCell(Lua_HeroRebuildBtnItem);
    self.btnList:setButtonItem(160, 58);
    self.btnList:setLocation(2, -336);
    self.btnList:setClickCallBack(self, self.onBtnClick);

    self.subBtn:addClickFuntion(self, self.onOpenTipsClick);
    self.help:addClickFuntion(self, self.onHelpBtnClick);

    self:addLuaEvent("UPDATE_HERO_RESHAPE_INFO", self, self.showItemInfo);
end

function Lua_HeroRebuildWindow:dispose()
    if self.dragList ~= nil then
        self.dragList:dispose();
        self.dragList = nil;
    end
    if self.heroItemIcon ~= nil then
        self.heroItemIcon:dispose();
        self.heroItemIcon = nil;
    end
    if self.btnList ~= nil then
        self.btnList:dispose();
        self.btnList = nil;
    end
    if self.costIconItem ~= nil then
        self.costIconItem:dispose()
        self.costIconItem = nil;
    end
    self.data = nil;
    self:superCall("dispose");
end

-- 英雄展示数据  
function Lua_HeroRebuildWindow:showWin(data)
    self.data = data;

    if self.isFirstIn == nil then
        self.isFirstIn = true;

        local arr = Array();
        arr:add({types = 1, nameStr = LanUtil.getValue(126038)});
        arr:add({types = 2, nameStr = LanUtil.getValue(126084)});
        self.btnList:setData(arr);
        self.btnList:setSelected(1);
    end
end

function Lua_HeroRebuildWindow:onBtnClick(index, data)
    if self.index ~= nil and self.index == index then return end

    if self.index == 2 and DataCenter.heroAssemblyData.rollbackState == 0 then
        self.btnList:setSelected(1);
        OperateAlert.showLangValue(126406);
        return;
    end

    self.index = index;

    if self.costIconItem ~= nil then
        self.costIconItem:setEnable(false);
    end

    if self.index == 1 then
        self:updateRebuildInfo(self.data);
    else
        self:updateReshapeInfo();
    end
    self.titleTxt.text = data.nameStr;
end

--------------------------------------- 重生功能 ---------------------------------------

function Lua_HeroRebuildWindow:updateRebuildInfo(data)
    self.heroItemIcon:setData(data);
    self.heroItemIcon:showFightIcon(nil);

    self.show_des.text = LanUtil.formateStr(126040,self.data.name);

    local arr = DataCenter.heroData:rebuildInfo(data);
    self.dragList:setArrayData(arr);

    self.need_money = DataCenter.heroUtil:rebuild_money(data.level);
    if self.need_money == 0 then
        self.tipTxt.text = "";
    else
        self.tipTxt.text = LanUtil.formateStr(126039,tostring(self.need_money));
    end
end

function Lua_HeroRebuildWindow:onOpenTipsClick()
    if self.index == 1 then
        if not self.data.isCultivateHero then
            OperateAlert.showLangValue(126085);
            return;
        end

        local tipsData = {
            des = LanUtil.getValue(126042),
            posY = 30,
            time = DataCenter.heroUtil.rebuild_down_time,
            btnType = 1,
            owner = self,
            sureFun = self.onRebuildBtnClick
        };
        if self.need_money ~= 0 then -- 免费
            local str = spliceIconStrById(Lua_ResourcesDefine.DIAMOND);
            tipsData.des = LanUtil.formateStr(126043, str, tostring(self.need_money));
            tipsData.posY = 34;
            time = 0
        end
        Lua_WindowUtil.openWin("Lua_TipsWindow", nil, tipsData);
    else
        self:onReshapeClick();
    end
end

function Lua_HeroRebuildWindow:onRebuildBtnClick()
    local have_num = DataCenter.packData:getItemCountById(Lua_ResourcesDefine.DIAMOND);
    if have_num < self.need_money then
        DataCenter.packUtil:openPathWindow(Lua_ResourcesDefine.DIAMOND, false);
        return;
    end
    Lua_ProxyManager.getProxy("Lua_HeroProxy"):sHeroRebuild(self.data.unique_id);
    self:hide();
end

--重修规则
function Lua_HeroRebuildWindow:onHelpBtnClick()
    local langValue = 126044;
    if self.index == 2 then
        langValue = 126087;
    end
    local tipsData = { des = LanUtil.getValue(langValue), posX = 98, posY = -456 };
    Lua_WindowUtil.openWin("Lua_InstructionTipsWindow", Lua_WinParam.ACTION_OPEN, tipsData);
end

--------------------------------------- 回退功能 ---------------------------------------

function Lua_HeroRebuildWindow:updateReshapeInfo()
    local canReshape = false;
    if self.data.star >= DataCenter.heroUtil.rebuild_limit and self.data.star <= DataCenter.heroUtil.rollback_high then
        local openState, openDay = DataCenter.heroUtil:getNewHeroFuncOpenState(self.data.id, Lua_NewHeroFuncOpen.hero_palace);
        if not self.data.is_league_transaction and not self.data.trial_state and openState then
            canReshape = true;
        end
    end
    self.canReshape = canReshape;

    local rate = DataCenter.heroUtil.rebuild_ratio * 100;
    self.show_des.text = LanUtil.formateStr(126082, self.data.name, rate);

    self.remainTime = DataCenter.heroUtil.rollback_num - DataCenter.heroAssemblyData.rollbackTime;
    if self.remainTime < 0 then
        self.remainTime = 0;
    end

    local cfgData = DataCenter.heroUtil:getHeroAwakenStarConfigInfo(self.data.awaken_star_id);
    self.isUseFree = cfgData.use_free_rollback == 1;
    if self.remainTime > 0 and self.isUseFree then
        self.tipTxt.text = LanUtil.formateStr(126432, tostring(self.remainTime));
    else
        self.tipTxt.text = "";
        if self.costIconItem == nil then
            self.costIconItem = Lua_ConsumeIconItem.new(self.content);
            self.costIconItem:setStyle(Lua_MyUISettings.defaultFontName, 26, "565656");
            self.costIconItem:setLocation(0, -186, 0);

            self.costInfo = cfgData.rollback_consume;
            if self.costInfo ~= nil then
                self.costIconItem:setData(self.costInfo);
            end
        else
            self.costIconItem:setEnable(true);
        end
    end

    if self.data.isCultivateStar and self.canReshape then
        Lua_ProxyManager.getProxy("Lua_HeroAssemblyProxy"):sHeroReshapeItem(self.data.unique_id);
    else
        self.dragList:setArrayData(nil);
    end
end

function Lua_HeroRebuildWindow:showItemInfo(msg)
    if msg == nil then
        return
    end

    local tab = DataCenter.packData:getRewardDic(msg.item_list);
    local arr = DataCenter.packData:getRewardList(tab); 
    if arr:getSize() > 0 then
        local vo;
        local siftInfo = DataCenter.heroUtil.siftInfo;
        local campIdx;
        for i = 1, arr:getSize() do
            vo = arr[i];
            if vo.main_type == Lua_PackDefine.HERO then -- 英雄
                campIdx = siftInfo:indexOf(vo.campType);
                vo.sort = vo.quality * 100 + vo.quality_star * 10 - campIdx;
            elseif vo.main_type == Lua_PackDefine.EQUIP then -- 装备
                vo.sort = -1000;
            elseif vo.main_type == Lua_PackDefine.RUNES then -- 符石
                vo.sort = -2000;
            elseif vo.main_type == Lua_PackDefine.MATERIALS then -- 消耗材料
                vo.sort = -3000;
            else
                vo.sort = -4000;
            end
        end
        arr:sort("sort", true);
        self.dragList:setArrayData(arr);
        self.dragList:moveToIndex(1, true);
    end
end

function Lua_HeroRebuildWindow:onReshapeClick()
    if not self.data.isCultivateStar then
        OperateAlert.showLangValue(126086);
        return;
    end

    if not self.canReshape then
        OperateAlert.showLangValue(126083);
        return;
    end

    if not DataCenter.heroData:isBagEnough(1) then
        OperateAlert.showLangValue(126433);
        return;
    end

    if self.data.is_resonance == true then--同调器中
        self:showRemoveResonanceTips();
        return;
    end

    if self.data.isUpLineup and DataCenter.heroAssemblyData.removeLineupStateDic[self.data.unique_id] == nil then --是否显示下阵tips
        self:showHeroLineupTips();
        return;
    end

    if self.data.lock_state == true then--上锁tips
        self:showHeroUnlockTips();
        return;
    end

    if (self.remainTime > 0 and self.isUseFree) or (self.costInfo ~= nil and DataCenter.packData:getItemCountById(self.costInfo[1]) >= self.costInfo[2]) then
        Lua_ProxyManager.getProxy("Lua_HeroAssemblyProxy"):sHeroReshape(self.data.unique_id);
        self:hide();
    else
        OperateAlert.showLangValue(126415);
    end
end

--同调器tips
function Lua_HeroRebuildWindow:showRemoveResonanceTips()
    local tipData = { des = LanUtil.getValue(126919), btnType = 1, owner = self, sureFun = self.sendDemount };
    Lua_WindowUtil.openWin("Lua_TipsWindow", Lua_WinParam.ACTION_OPEN, tipData);
end

--从同调器中卸下
function Lua_HeroRebuildWindow:sendDemount()
    local grid_id = DataCenter.lifeTreeData:getGridIdByUid(self.data.unique_id);
    if grid_id == 0 then
        return;
    end
    Lua_ProxyManager.getProxy("Lua_LifeTreeProxy"):sDemountHero(grid_id);
end

--英雄下阵
function Lua_HeroRebuildWindow:showHeroLineupTips()
    local tipData = { des = LanUtil.formateStr(126221, self.data.upLineupName), btnType = 1, owner = self, sureFun = self.onHeroLineup };
    Lua_WindowUtil.openWin("Lua_TipsWindow", Lua_WinParam.ACTION_OPEN, tipData);
end

--英雄下阵
function Lua_HeroRebuildWindow:onHeroLineup()
    local bDownLineup;
    local showName;
    bDownLineup, showName = DataCenter.heroAssemblyData:checkLineupNumState(self.data.unique_id);
    if bDownLineup then--是否可以下阵
        OperateAlert.showLangValue(126222);
        DataCenter.heroAssemblyData.removeLineupStateDic[self.data.unique_id] = 1;
    else
        if self.data:isInLineup(49) or self.data:isInLineup(50) or self.data:isInLineup(51) then
            OperateAlert.showLangValue(701096);
        else
            OperateAlert.show(LanUtil.formateStr(126223, showName));
        end
    end
end

--英雄解锁tips
function Lua_HeroRebuildWindow:showHeroUnlockTips()
    local tipData = { des = LanUtil.getValue(126219), btnType = 1, owner = self, sureFun = self.sendUnlock };
    Lua_WindowUtil.openWin("Lua_TipsWindow", Lua_WinParam.ACTION_OPEN, tipData);
end

--英雄解锁
function Lua_HeroRebuildWindow:sendUnlock()
    Lua_ProxyManager.getProxy("Lua_HeroProxy"):sHeroLock(self.data.unique_id, 0);
end





























-- 重修Item
Lua_HeroRebuildCell = class("Lua_HeroRebuildCell", Lua_ListCell);
function Lua_HeroRebuildCell:ctor(p)
    self:superCall("ctor", p);
end

function Lua_HeroRebuildCell:buildShowItem()
    self:superCall("buildShowItem");
    self.heroItemIcon = Lua_ItemIcon.new(self.content);
    self.heroItemIcon:setScale(0.86,0.86,0.86);
    self.heroItemIcon:setCanClick(false);
end

function Lua_HeroRebuildCell:dispose()
    if self.heroItemIcon ~= nil then
        self.heroItemIcon:dispose();
        self.heroItemIcon = nil;
    end
    self.data = nil;
    self:superCall("dispose");
end

function Lua_HeroRebuildCell:setData(data)
    self.data = data;
    self.heroItemIcon:setData(data);
end

function Lua_HeroRebuildCell:onPressClick(go)
    if self.data ~= nil then
        DataCenter.packUtil:showItemInfo(self.data);
    end
end
































Lua_HeroRebuildBtnItem = class("Lua_HeroRebuildBtnItem", Lua_ButtonCell);

function Lua_HeroRebuildBtnItem:ctor(p)
    self:superCall("ctor", p, "HeroRebuildBtnItem_skin");
end

function Lua_HeroRebuildBtnItem:buildShowItem()
    self:superCall("buildShowItem");

    self.btnBg.clickScale = false;
    self.btnBg:addClickFuntion(self, self.onPressClick);
end

function Lua_HeroRebuildBtnItem:dispose()
    self.data = nil;
    self:superCall("dispose");
end

function Lua_HeroRebuildBtnItem:setData(data)
    self.data = data;
    self.btnTxt.text = self.data.nameStr;
end

function Lua_HeroRebuildBtnItem:setSelected(index)
    if self.index == index then
        self.btnTxt.colorStr = Lua_ColorDefine.transColorStr("8F5123");
        self.btnBg.alpha = 1;
    else
        self.btnTxt.colorStr = Lua_ColorDefine.transColorStr("594d4d");
        self.btnBg.alpha = 0;
    end
end