-- 战技 Panel
Lua_HeroCharmDevelopPanel = class("Lua_HeroCharmDevelopPanel", Lua_DisplayObject);

function Lua_HeroCharmDevelopPanel:ctor(p)
	self:superCall("ctor", p, "HeroCharmDevelopPanel_skin");
end

function Lua_HeroCharmDevelopPanel:buildShowItem()
	self:superCall("buildShowItem");

	self:addLuaEvent("UPDATE_HERO_CHARM_INFO", self, self.updateData);
	self:addLuaEvent("UPDATE_CHARM_UPGRADE", self, self.updateData)

	self.itemIcon = Lua_ItemIcon.new(self.content);
	self.itemIcon:setLocation(0, 185);

	self.sureBtn:addClickFuntion(self, self.onSureBtnClick);
end

function Lua_HeroCharmDevelopPanel:dispose()
	if self.itemIcon ~= nil then
		self.itemIcon:dispose();
		self.itemIcon = nil;
	end
	if self.propItemArr ~= nil then
		self.propItemArr:dispose();
		self.propItemArr = nil;
	end
	if self.costItemArr ~= nil then
		self.costItemArr:dispose();
		self.costItemArr = nil;
	end
	self:superCall("dispose")
end

function Lua_HeroCharmDevelopPanel:setData(charmUid)
	self.charmUid = charmUid;
	self:updateData();
end

function Lua_HeroCharmDevelopPanel:updateData()
	self.heroCharmVo = DataCenter.packData:getItemVoByUnId(self.charmUid);
	self.itemIcon:setData(self.heroCharmVo);
	self.itemIcon:showNum(0);

	local isUp = self.heroCharmVo.level < self.heroCharmVo.max_level;
	if isUp then
		self.nextTxt.text = LanUtil.formateStr("Lv. {1}", self.heroCharmVo.level + 1);
	else
		self.nextTxt.text = "";
	end
	self.curTxt.text = LanUtil.formateStr("Lv. {1}", self.heroCharmVo.level);

	self.arrowIcon:setEnable(isUp);
	self.sureBtn:setEnable(isUp);
	self.maxTxt:setEnable(not isUp);

	self:showPropInfo();
	self:showCostInfo();
end

function Lua_HeroCharmDevelopPanel:showPropInfo()
	if self.propItemArr == nil then
		self.propItemArr = Array();
	end

	local propArr = DataCenter.heroCharmUtil:getComAttrUpVoArr(self.heroCharmVo.levelId);
	local count = propArr:getSize();
	local item;
	for i = 1, count do
		item = self:getPropItem(i);
		item:setLocation(0, -40 - (i - 1) * 50, 0);
		item:setData(propArr[i], 0, 0);
	end

	propArr = DataCenter.heroCharmUtil:getSpecAttrUpVoArr(self.heroCharmVo.levelId);
	local limtLv;
	for i = 1, propArr:getSize() do
		item = self:getPropItem(count + i);
		item:setLocation(0, -40 - (count + i - 1) * 50, 0);

		limtLv = DataCenter.heroCharmUtil:getSpecUnlockLv(self.heroCharmVo.levelId, propArr[i].id);
		item:setData(propArr[i], self.heroCharmVo.level, limtLv);
	end

	count = count + propArr:getSize();
	local len = self.propItemArr:getSize();
	if len > count then
		for i = count + 1, len do
			self.propItemArr[i]:setEnable(false);
		end
	end
end

function Lua_HeroCharmDevelopPanel:getPropItem(idx)
	local item = self.propItemArr[idx];
	if item == nil then
		item = Lua_HeroCharmDevelopCompareItem.new(self.content);
		self.propItemArr:add(item);
	else
		item:setEnable(true);
	end
	return item;
end

function Lua_HeroCharmDevelopPanel:showCostInfo()
	if self.costItemArr == nil then
		self.costItemArr = Array();
	end

	local list = DataCenter.heroCharmUtil:lvlup_cost(self.heroCharmVo.levelId);
	local count = list ~= nil and # list or 0;
	local num = self.costItemArr:getSize();
	local len = count > num and count or num;
	local halfW = (count - 1) * 50 / 2;
	for i = 1, len do
		item = self.costItemArr[i];
		if item == nil then
			item = Lua_HeroCharmDevelopCostItem.new(self.content);
			self.costItemArr:add(item);
		end

		if i <= count then
			item:setLocation(10 + (i - 1) * 100 - halfW, -315, 0);
			item:setData(list[i]);
		end
		item:setEnable(i <= count);
	end
end

function Lua_HeroCharmDevelopPanel:onSureBtnClick()
	local list = DataCenter.heroCharmUtil:lvlup_cost(self.heroCharmVo.levelId);
	local costId = DataCenter.packData:checkConsumeEnough(list);
	if costId == nil then
		Lua_ProxyManager.getProxy("Lua_HeroCharmProxy"):sCharmUpgrade(self.charmUid);
	else
		DataCenter.packUtil:openPathWindow(costId);
	end
end



























Lua_HeroCharmDevelopCompareItem = class("Lua_HeroCharmDevelopCompareItem", Lua_DisplayObject);

function Lua_HeroCharmDevelopCompareItem:ctor(p)
	self:superCall("ctor", p, "HeroCharmDevelopCompareItem_skin");
end

function Lua_HeroCharmDevelopCompareItem:buildShowItem()
	self:superCall("buildShowItem");

	self.leftItem = Lua_HeroCharmAttrItem.new(self.content, self.showType);
end

function Lua_HeroCharmDevelopCompareItem:dispose()
	if self.leftItem ~= nil then
		self.leftItem:dispose();
		self.leftItem = nil;
	end
	if self.rightItem ~= nil then
		self.rightItem:dispose();
		self.rightItem = nil;
	end
	self:superCall("dispose")
end

function Lua_HeroCharmDevelopCompareItem:setData(attrVo, level, limtLv)
	self.leftItem:setData(attrVo, 1, level, limtLv);

	if attrVo.nextValue > 0 then
		if self.rightItem == nil then
			self.rightItem = Lua_HeroCharmAttrItem.new(self.content);
			self.rightItem:setLocation(100, 0, 0);
		end
		self.rightItem:setData(attrVo, 2, level + 1, limtLv);
		self.rightItem:setEnable(true);

		self.leftItem:setLocation(-235, 0, 0);
	else
		if self.rightItem ~= nil then
			self.rightItem:setEnable(false);
		end
		self.leftItem:setLocation(-70, 0, 0);
	end
	self.arrowIcon:setEnable(attrVo.nextValue > 0);
end
































Lua_HeroCharmDevelopCostItem = class("Lua_HeroCharmDevelopCostItem", Lua_DisplayObject);

function Lua_HeroCharmDevelopCostItem:ctor(p)
	self:superCall("ctor", p, "HeroCharmDevelopCostItem_skin");
end

function Lua_HeroCharmDevelopCostItem:buildShowItem()
	self:superCall("buildShowItem");

	self.itemIcon = Lua_ItemIcon.new(self.content);
	self.itemIcon:setLocation(0, 0, 0);
	self.itemIcon.canClick = true;
end

function Lua_HeroCharmDevelopCostItem:dispose()
	if self.itemIcon ~= nil then
		self.itemIcon:dispose();
		self.itemIcon = nil;
	end
	self:superCall("dispose")
end

function Lua_HeroCharmDevelopCostItem:setData(data)
	if self.itemVo == nil then
		self.itemVo = Lua_ToolVo.createToolVo(data[1]);
	else
		self.itemVo:setData(data[1]);
	end
	self.itemIcon:setData(self.itemVo);

	local packNum = DataCenter.packData:getItemCountById(data[1]);
	local colorStr = "FFFFFF";
    if data[2] > packNum then
        colorStr = "ee2c24";
    end
	self.showTxt.text = Lua_ColorDefine.getColorStr(colorStr, numberTrans(data[2]).."/"..numberTrans(packNum));
end