-- 成圣之路 Panel
Lua_HeroHolyTaskPanel = class("Lua_HeroHolyTaskPanel", Lua_DisplayObject);

function Lua_HeroHolyTaskPanel:ctor(p)
    self:superCall("ctor", p, "HeroHolyTaskPanel_skin");
end

function Lua_HeroHolyTaskPanel:buildShowItem()
    self:superCall("buildShowItem");

    self.btnArr = Array();

    self.ringBar.typeValue = 3;
    self.ringBar.fillMethodValue = 4;
    self.ringBar.fillOrigin = 0;
    self.ringBar.fillAmount = 0;

    self.goBtn:addClickFuntion(self, self.onGoBtnClick);
    self.beyondBtn:addClickFuntion(self, self.onBeyondBtnClick);

    self:addLuaEvent("HEROHOLY_TASKINFO_UPDATE", self, self.updateData);
    self:addLuaEvent("CLICK_HEROHOLY_TASK_BTN", self, self.updateBtnSelect);
end

function Lua_HeroHolyTaskPanel:dispose()
    if self.btnArr ~= nil then
        self.btnArr:dispose();
        self.btnArr = nil;
    end
    if self.bgEff ~= nil then
        self.bgEff:dispose();
        self.bgEff = nil;
    end
    if self.btnEff ~= nil then
        self.btnEff:dispose();
        self.btnEff = nil;
    end
    self.taskData = nil;
    self.heroVo = nil;
    self:superCall("dispose");
end

function Lua_HeroHolyTaskPanel:setData(heroVo)
    self.heroVo = heroVo;

    self.roleImg:setUrl(heroVo.halfPicPath);
    
    Lua_ProxyManager.getProxy("Lua_HeroHolyProxy"):sTaskInfo();
end

function Lua_HeroHolyTaskPanel:updateData()
    local taskArr = DataCenter.heroHolyData:getTaskVoArr();
    local data;
    local item;
    local selectIdx = taskArr:getSize();
    local lineStr = "line";
    local state;
    for i = 1, taskArr:getSize() do
        data = taskArr[i]
        item = self.btnArr[i]; 
        if item == nil then
            item = Lua_HeroHolyTaskBtnItem.new(self.content);
            self.btnArr:add(item);
        end
        item:setData(data, self.heroVo.unique_id);
        item:setLocation(data.btn_pos[1], data.btn_pos[2], 0);

        if data.cond_id ~= nil then
            state = data.state == 1;
        else
            state = data:curStateByUid(self.heroVo.unique_id)
        end
        if state then
            self[lineStr .. i]:setAltas("hero_holy_atlas", "xui_cszl_Progress _02_f");
        else
            self[lineStr .. i]:setAltas("hero_holy_atlas", "xui_cszl_Progress _02_b");
        end

        if not state then
            if i < selectIdx then
                selectIdx = i;
            end
        end
    end

    for i = 1, self.btnArr:getSize() do
        self.btnArr[i]:updateSelect(i == selectIdx);
    end

    local curNum, num = DataCenter.heroHolyData:getTaskFinishInfo(self.heroVo.unique_id);
    self.isFinishTask = curNum >= num;
    self.titleTxt.text = LanUtil.formateStr(778004, curNum, num);
    self.ringBar.fillAmount = curNum / num;

    self:updateTaskInfo(taskArr[selectIdx]);
end

function Lua_HeroHolyTaskPanel:updateBtnSelect(data)
    local item;
    for i = 1, self.btnArr:getSize() do
        item = self.btnArr[i];
        item:updateSelect(item.data.id == data.id);
    end
    self:updateTaskInfo(data);
end

function Lua_HeroHolyTaskPanel:updateTaskInfo(data)
    self.taskData = data;

    self.taskNameTxt.text = data.title;
    self.taskTitleTxt.text = data.desc;
    local num;
    local maxNum = data.maxProgress;
    if data.cond_id ~= nil then
        num = data.progress;
    else
        num = data:curProgressByUid(self.heroVo.unique_id);
    end

    self.progressBar:setMaxValue(maxNum);
    self.progressBar:setValue(num);
    self.progressBar:setText(LanUtil.formateStr(778005, num, maxNum));

    if num >= maxNum then
        self.goBtn:setLangValue(778006);
        self.goBtn:setMouseEnable(false);
    else
        self.goBtn:setLangValue(778007);
        self.goBtn:setMouseEnable(true);
    end
    
    self.taskIcon:setEnable(not self.isFinishTask);
    self.taskNameTxt:setEnable(not self.isFinishTask);
    self.taskTitleTxt:setEnable(not self.isFinishTask);
    self.progressBar:setEnable(not self.isFinishTask);
    self.goBtn:setEnable(not self.isFinishTask);
    self.beyondBtn:setEnable(self.isFinishTask);
    self:showEffect(self.isFinishTask);
end

function Lua_HeroHolyTaskPanel:onGoBtnClick()
    if self.taskData ~= nil then
        if self.taskData.cond_id ~= nil then
            DataCenter.funcPathUtil:gotoFunction(self.taskData.path_id, true);
        else
            if self.taskData.id == 3 then
                Lua_MsgUtil.callFunc("SWITCH_HEROHOLY_PANEL", Lua_HeroHolyData.HALF_HOLY);
            elseif self.taskData.id == 4 then
                Lua_MsgUtil.callFunc("SWITCH_HEROHOLY_PANEL", Lua_HeroHolyData.HOLY_SOUL);
            end
        end
    end
end

function Lua_HeroHolyTaskPanel:onBeyondBtnClick()
    Lua_ProxyManager.getProxy("Lua_HeroHolyProxy"):sHeroUpStar(self.heroVo.unique_id);
    Lua_WindowUtil.openWin("Lua_HeroHolyWindow", Lua_WinParam.ACTION_CLOSE);
end


function Lua_HeroHolyTaskPanel:showEffect(val)
    if val then
        if self.bgEff == nil then
            self.bgEff = UICreate.createUIEffect(self.content, "/effects/uiEffects/ui_cs_02", "ui_cs_02", 0, 0);
            self.btnEff = UICreate.createUIEffect(self.content, "/effects/uiEffects/ui_zx_tiaozhan_1", "ui_zx_tiaozhan_1", 1, -321);
        else
            self.bgEff:setEnable(true);
            self.btnEff:setEnable(true);
        end
    else
        if self.bgEff ~= nil then
            self.bgEff:setEnable(false);
            self.btnEff:setEnable(false);
        end
    end
end





















Lua_HeroHolyTaskBtnItem = class("Lua_HeroHolyTaskBtnItem", Lua_DisplayObject);

function Lua_HeroHolyTaskBtnItem:ctor(p)
    self:superCall("ctor", p, "HeroHolyTaskBtnItem_skin");
end

function Lua_HeroHolyTaskBtnItem:buildShowItem()
    self:superCall("buildShowItem");

    self.stateBg:addClickFuntion(self, self.onBtnClick);
end

function Lua_HeroHolyTaskBtnItem:dispose()
    self.data = nil;
    self:superCall("dispose");
end

function Lua_HeroHolyTaskBtnItem:setData(data, heroUid)
    self.data = data;

    local state;
    if data.cond_id ~= nil then
        state = data.state == 1;
    else
        state = data:curStateByUid(heroUid);
    end

    if state then
        self.stateBg:setAltas("hero_holy_atlas", "xui_cszl_button_02");
        self.nameTxt.colorStr = Lua_ColorDefine.transColorStr("652e06");
    else
        self.stateBg:setAltas("hero_holy_atlas", "xui_cszl_button_01");
        self.nameTxt.colorStr = Lua_ColorDefine.transColorStr("7ae888");
    end
    self.nameTxt.text = data.btn_name;
end

function Lua_HeroHolyTaskBtnItem:updateSelect(val)
    self.selectBg:setEnable(val);
end

function Lua_HeroHolyTaskBtnItem:onBtnClick()
    Lua_MsgUtil.callFunc("CLICK_HEROHOLY_TASK_BTN", self.data);
end